BwEditTextField class

Inheritance

Constructors

BwEditTextField({bool? enabled, bool? readOnly, String? hintText, TextEditingController? controller, double? borderRadius, ValueChanged<String>? onChanged, List<TextInputFormatter>? inputFormatters, FormFieldValidator<String>? validator, String? infoText, ValueChanged<String?>? onSaved, FocusNode? focusNode, ValueChanged<String>? onFieldSubmitted, Function? onFocusChanged, String? errorText, AutovalidateMode? autoValidateMode, String? label, InputDecoration? decoration, Widget? suffixIcon, Widget? prefixIcon, TextInputAction? textInputAction, bool? obscureText, TextInputType? keyboardType, int? maxLength, Widget? counterWidget, int maxLines = 1, Function? onEditingCompleted, TextCapitalization? textCapitalization, bool showError = false, double? height, VoidCallback? onErrorCleared, Iterable<String>? autofillHints, Key? key, GestureTapCallback? onTap, Color? fillColor, double? borderWidth = 1, bool? hasBorder = true, bool? autoFocus = false, String? initialValue, bool? counterTextRequired, Color? cursorColor, Color? hintColor, Color? borderColor})
const

Properties

autofillHints Iterable<String>?
final
autoFocus bool?
final
autoValidateMode AutovalidateMode?
final
borderColor Color?
final
borderRadius double?
final
borderWidth double?
final
controller TextEditingController?
final
counterTextRequired bool?
final
counterWidget Widget?
final
cursorColor Color?
final
decoration InputDecoration?
final
enabled bool?
final
errorText String?
final
fillColor Color?
final
focusNode FocusNode?
final
hasBorder bool?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
hintColor Color?
final
hintText String?
final
infoText String?
final
initialValue String?
final
inputFormatters List<TextInputFormatter>?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType TextInputType?
final
label String?
final
maxLength int?
final
maxLines int
final
obscureText bool?
final
onChanged ValueChanged<String>?
final
onEditingCompleted Function?
final
onErrorCleared VoidCallback?
final
onFieldSubmitted ValueChanged<String>?
final
onFocusChanged Function?
final
onSaved ValueChanged<String?>?
final
onTap GestureTapCallback?
final
prefixIcon Widget?
final
readOnly bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showError bool
final
suffixIcon Widget?
final
textCapitalization TextCapitalization?
final
textInputAction TextInputAction?
final
validator FormFieldValidator<String>?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<BwEditTextField>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited